<?php

    function wda_renaissance_files() {
        wp_enqueue_style('wda_renaissance_styles', get_theme_file_uri('/assets/css/front-end/style-index.css'));
        wp_enqueue_style('wda_renaissance_additional_styles', get_theme_file_uri('/assets/css/front-end/index.css'));
        wp_enqueue_style('font-awesome', get_template_directory_uri().'/assets/icons/font-awesome/css/font-awesome.min.css');
        wp_enqueue_script('wda-renaissance-js', get_theme_file_uri('/assets/js/front-end/index.js'), array('jquery'), '1.0', true);
        wp_enqueue_style( 'wda-theme-fonts', wda_enqueue_fonts_url(), array(), null );
    }

    add_action('wp_enqueue_scripts', 'wda_renaissance_files');

    function wda_renaissance_theme_features() {
        register_nav_menu('primary_menu', esc_html__( 'Primary Menu', 'renaissance-wda'));
        load_theme_textdomain( 'renaissance-wda', get_template_directory() . '/languages' ); 
        add_theme_support( 'custom-logo' );
        add_theme_support('title-tag');
        add_theme_support('post-thumbnails');
        add_theme_support('wp-block-styles');
        add_theme_support('widgets');
        add_theme_support('widgets-block-editor');
        add_theme_support( 'automatic-feed-links' );
        add_theme_support( "responsive-embeds" );
        add_theme_support( "align-wide" );
        add_image_size('wdabannerImageSize', 1500, 300, true);
        add_editor_style( 'editor-style.css' );
    }

    add_action('after_setup_theme', 'wda_renaissance_theme_features');

    
    ##################------ INCLUDING FILES ------##################
    require( get_template_directory() . '/inc/front-end/walker.php' );
    require( get_template_directory() . '/inc/front-end/wda-custom-styles.php' );
    require( get_template_directory() . '/inc/customizer/customizer.php' );
    require( get_template_directory() . '/inc/admin/wda-add-default-options.php' );

    ##################------ Logo ------##################


    function wda_custom_logo_setup() {
        $defaults = array(
            'height'               => 100,
            'width'                => 400,
            'flex-height'          => true,
            'flex-width'           => true,
            'header-text'          => array( 'site-title', 'site-description' ),
            'unlink-homepage-logo' => true, 
        );
        add_theme_support( 'custom-logo', $defaults );
    }
    add_action( 'after_setup_theme', 'wda_custom_logo_setup' );

    ##################------ Fonts ------##################

    function wda_enqueue_fonts_url() {
            $wdaFontFamily = get_theme_mod( 'wda_renaissance_fonts_setting' );
            $fonts_url = '';
            $fonts     = array();
            $subsets   = '';
            if (  $wdaFontFamily == "Roboto"  ) {
                $fonts[] = "Roboto:300,400,500,600,700";
            }
            if (  $wdaFontFamily == "Poppins"  ) {
                $fonts[] = "Poppins:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Open Sans"  ) {
                $fonts[] = "Open Sans:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Alegreya"  ) {
                $fonts[] = "Alegreya:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Alegreya Sans"  ) {
                $fonts[] = "Alegreya Sans:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Lato"  ) {
                $fonts[] = "Lato:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Montserrat"  ) {
                $fonts[] = "Montserrat:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Oswald"  ) {
                $fonts[] = "Oswald:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Raleway"  ) {
                $fonts[] = "Raleway:300,400,500,600,700,800,900";
            }
            if (  $wdaFontFamily == "Inknut Antiqua"  ) {
                $fonts[] = "Inknut Antiqua:300,400,500,600,700,800,900";
            }
            $is_ssl = is_ssl() ? 'https' : 'http';
        
            if (  $fonts  ) {
                $fonts_url = add_query_arg( array(
                    'family' => urlencode( implode( '|', $fonts  ) ),
                    'subset' => urlencode( $subsets ),
                ), "$is_ssl://fonts.googleapis.com/css" );
            }
            return esc_url($fonts_url);
    }

    ##################------ REGISTERING WIDGETS ------##################

    function wda_widgets_init() {
        $defaults = array(
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        );
    
        register_sidebar( array_merge( $defaults, array(
            'id'          => 'wda_blog_sidebar',
            'name'        => esc_html__( 'Blog Sidebar', 'renaissance-wda'),
            'description' => esc_html__( 'Default Sidebar of the blog.', 'renaissance-wda'),
        ) ) );	
    
        register_sidebar( array_merge( $defaults, array(
            'id'          => 'wda_footer_widget_01',
            'name'        => esc_html__( 'Footer Widget 1', 'renaissance-wda'),
            'description' => esc_html__( 'The footer area of the widget.', 'renaissance-wda'),
        ) ) );
    
        register_sidebar( array_merge( $defaults, array(
            'id'          => 'wda_footer_widget_02',
            'name'        => esc_html__( 'Footer Widget 2', 'renaissance-wda'),
            'description' => esc_html__( 'The footer area of the widget.', 'renaissance-wda'),
        ) ) );
    
        register_sidebar( array_merge( $defaults, array(
            'id'          => 'wda_footer_widget_03',
            'name'        => esc_html__( 'Footer Widget 3', 'renaissance-wda'),
            'description' => esc_html__( 'The footer area of the widget.', 'renaissance-wda'),
        ) ) );
         
    }
    add_action( 'widgets_init', 'wda_widgets_init' );   


    ##################------ CHANGING COMMENTS FIELDS STANDARD ORDERING ------##################

    function wda_comment_fields_custom_order ($fields) {
        $comment_field = $fields['comment'];
        $author_field = $fields['author'];
        $email_field = $fields['email'];
        $url_field = $fields['url'];
        $cookies_field = $fields['cookies'];
        unset( $fields['comment'] );
        unset( $fields['author'] );
        unset( $fields['email'] );
        unset( $fields['url'] );
        unset( $fields['cookies'] );
        ?><?php
        $fields['author'] = '<input id="author" class="wda-comment-author-field" name="author" value="" placeholder="'.esc_attr__( 'Name*', 'renaissance-wda').'" size="30" maxlength="245"  type="text" required="required">';
        $fields['email'] = '<input id="email" class="wda-comment-email-field" name="email" type="email" value="" placeholder="'.esc_attr__( 'Email*', 'renaissance-wda').'" size="30" maxlength="100" aria-describedby="email-notes" required="required">';	
        $fields['comment'] = '<textarea id="comment" class="wda-comment-textarea-field" name="comment" cols="45" rows="8" maxlength="65525" placeholder="'.esc_attr__( 'Comment*', 'renaissance-wda').'" required="required"></textarea>';
        $fields['cookies'] = $cookies_field;
        return $fields;
    }
    
    add_filter('comment_form_fields', 'wda_comment_fields_custom_order');





    
